==> electric-6.06.tar.gz: electric-6.06/src/include/usrdiacom.h <==
/*
 * Electric(tm) VLSI Design System
 *
 * File: usrdiacom.h
 * Special command dialogs, headers
 * Written by: Steven M. Rubin, Static Free Software
 *
 * Copyright (c) 2000 Static Free Software.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 *
 * Static Free Software
 * 4119 Alpine Road
 * Portola Valley, California 94028
 * info@staticfreesoft.com
 */

#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
extern "C"
{
#endif

INTBIG us_3ddepthdlog();
INTBIG us_aboutdlog(void);
INTBIG us_alignmentdlog(void);
INTBIG us_annularringdlog(void);
INTBIG us_arcsizedlog(char*[]);
INTBIG us_arraydlog(char*[]);
INTBIG us_artlookdlog(void);
INTBIG us_attrenumdlog(void);
INTBIG us_attributesdlog(void);
INTBIG us_attrparamdlog(void);
void us_colormixdlog(char *overlayernames[]);
INTBIG us_copyfacetdlog(char*);
INTBIG us_createtodlog(char*[]);
INTBIG us_defarcdlog(void);
INTBIG us_defnodedlog(void);
INTBIG us_deftextdlog(char*);
INTBIG us_dependentlibdlog(void);
INTBIG us_editfacetdlog(char*);
INTBIG us_facetdlog(void);
INTBIG us_facetlist(void);
INTBIG us_facetselect(char*, char*[], BOOLEAN);
INTBIG us_findtextdlog(void);
INTBIG us_frameoptionsdlog(void);
INTBIG us_generaloptionsdlog(void);
INTBIG us_globalsignaldlog(void);
INTBIG us_griddlog(void);
INTBIG us_helpdlog(char*);
INTBIG us_highlayerlog(void);
INTBIG us_iconstyledlog(void);
INTBIG us_javaoptionsdlog(void);
INTBIG us_lambdadlog(void);
INTBIG us_librarypathdlog(void);
INTBIG us_libtotechnologydlog(void);
INTBIG us_menudlog(char*[]);
INTBIG us_modtextsizedlog(void);
INTBIG us_newviewdlog(char*[]);
INTBIG us_nodesizedlog(char*[]);
INTBIG us_noyesalwaysdlog(char*, char*[]);
INTBIG us_noyescanceldlog(char*, char*[]);
INTBIG us_noyesdlog(char*, char*[]);
INTBIG us_oldlibrarydlog(void);
INTBIG us_optionsavingdlog(void);
INTBIG us_patterndlog(void);
INTBIG us_placetextdlog(void);
INTBIG us_plotoptionsdlog(void);
INTBIG us_portdisplaydlog(void);
INTBIG us_portdlog(char*[]);
INTBIG us_purelayernodedlog(char*[]);
INTBIG us_quickkeydlog(void);
INTBIG us_quitdlog(char*, INTBIG);
INTBIG us_renamedlog(INTBIG type);
INTBIG us_replacedlog(void);
INTBIG us_selectoptdlog(void);
INTBIG us_selectobjectdlog(INTBIG);
INTBIG us_showdlog(BOOLEAN);
INTBIG us_spreaddlog(void);
INTBIG us_technologydlog(char*, char*[]);
INTBIG us_techoptdlog(void);
INTBIG us_techvarsdlog(void);
INTBIG us_tracedlog(void);
INTBIG us_variablesdlog(void);
INTBIG us_viewdlog(INTBIG);
INTBIG us_visiblelayersdlog(char*);
INTBIG us_windowviewdlog(void);
INTBIG us_yesnodlog(char*, char*[]);

#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
}
#endif

==> electric-6.07.1.tar.gz: electric-6.07/src/include/usrdiacom.h <==
/* -*- tab-width: 4 -*-
 *
 * Electric(tm) VLSI Design System
 *
 * File: usrdiacom.h
 * Special command dialogs, headers
 * Written by: Steven M. Rubin, Static Free Software
 *
 * Copyright (c) 2000 Static Free Software.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 *
 * Static Free Software
 * 4119 Alpine Road
 * Portola Valley, California 94028
 * info@staticfreesoft.com
 */

#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
extern "C"
{
#endif

INTBIG us_3ddepthdlog();
INTBIG us_aboutdlog(void);
INTBIG us_alignmentdlog(void);
INTBIG us_annularringdlog(void);
INTBIG us_arcsizedlog(char*[]);
INTBIG us_arraydlog(char*[]);
INTBIG us_artlookdlog(void);
INTBIG us_attrenumdlog(void);
INTBIG us_attributesdlog(void);
INTBIG us_attrparamdlog(void);
INTBIG us_attrreportdlog(void);
void us_colormixdlog(char *overlayernames[]);
INTBIG us_copyfacetdlog(char*);
INTBIG us_createtodlog(char*[]);
INTBIG us_defarcdlog(void);
INTBIG us_defnodedlog(void);
INTBIG us_deftextdlog(char*);
INTBIG us_dependentlibdlog(void);
INTBIG us_editfacetdlog(char*);
INTBIG us_examineoptionsdlog(void);
INTBIG us_facetdlog(void);
INTBIG us_facetlist(void);
INTBIG us_facetselect(char*, char*[], INTBIG);
INTBIG us_findtextdlog(void);
INTBIG us_frameoptionsdlog(void);
INTBIG us_generaloptionsdlog(void);
INTBIG us_globalsignaldlog(void);
INTBIG us_griddlog(void);
INTBIG us_helpdlog(char*);
INTBIG us_highlayerlog(void);
INTBIG us_iconstyledlog(void);
INTBIG us_javaoptionsdlog(void);
INTBIG us_lambdadlog(void);
INTBIG us_librarypathdlog(void);
INTBIG us_libtotechnologydlog(void);
INTBIG us_menudlog(char*[]);
INTBIG us_modtextsizedlog(void);
INTBIG us_newviewdlog(char*[]);
INTBIG us_nodesizedlog(char*[]);
INTBIG us_noyesalwaysdlog(char*, char*[]);
INTBIG us_noyescanceldlog(char*, char*[]);
INTBIG us_noyesdlog(char*, char*[]);
INTBIG us_oldlibrarydlog(void);
INTBIG us_optionsavingdlog(void);
INTBIG us_patterndlog(void);
INTBIG us_placetextdlog(void);
INTBIG us_plotoptionsdlog(void);
INTBIG us_portdisplaydlog(void);
INTBIG us_portdlog(char*[]);
INTBIG us_purelayernodedlog(char*[]);
INTBIG us_quickkeydlog(void);
INTBIG us_quitdlog(char*, INTBIG);
INTBIG us_renamedlog(INTBIG type);
INTBIG us_replacedlog(void);
INTBIG us_selectoptdlog(void);
INTBIG us_selectobjectdlog(INTBIG);
INTBIG us_showdlog(BOOLEAN);
INTBIG us_spreaddlog(void);
INTBIG us_technologydlog(char*, char*[]);
INTBIG us_techoptdlog(void);
INTBIG us_techvarsdlog(void);
INTBIG us_tracedlog(void);
INTBIG us_variablesdlog(void);
INTBIG us_viewdlog(INTBIG);
INTBIG us_visiblelayersdlog(char*);
INTBIG us_windowviewdlog(void);
INTBIG us_yesnodlog(char*, char*[]);

typedef struct
{
	char *name;
	char *help;
} HELPERS;
extern HELPERS us_castofthousands[];
extern char *us_capacitancenames[], *us_resistancenames[], *us_inductancenames[],
	*us_currentnames[], *us_voltagenames[], *us_timenames[];

#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
}
#endif
